@@ -111,6 +111,7 @@ from .snappi import IsisSRSrgb
 from .snappi import IsisSRSrgbIter
 from .snappi import IsisSRSrlb
 from .snappi import IsisSRSrlbIter
+from .snappi import IsisGracefulRestart
 from .snappi import DeviceBgpRouter
 from .snappi import BgpV4Interface
 from .snappi import BgpV4Peer
@@ -362,6 +363,82 @@ from .snappi import Ospfv2V4RRExternalType1
 from .snappi import Ospfv2V4RRExternalType2
 from .snappi import Ospfv2V4RRNssaExternal
 from .snappi import Ospfv2V4RouteRangeIter
+from .snappi import DeviceMacsec
+from .snappi import DeviceMacsecEthernetInterface
+from .snappi import SecureEntity
+from .snappi import SecureEntityKeyGenerationProtocol
+from .snappi import Mka
+from .snappi import MkaBasic
+from .snappi import MkaBasicKeySource
+from .snappi import MkaBasicKeySourcePsk
+from .snappi import MkaBasicStartOffsetTime
+from .snappi import MkaBasicEndOffsetTime
+from .snappi import MkaBasicKeySourcePskIter
+from .snappi import MkaBasicSupportedCipherSuites
+from .snappi import MkaBasicRekeyMode
+from .snappi import MkaBasicRekeyModeTimerBased
+from .snappi import MkaBasicPskChainStartTime
+from .snappi import MkaBasicTimeUtc
+from .snappi import MkaKeyServer
+from .snappi import MkaTx
+from .snappi import MkaTxSc
+from .snappi import MkaTxScIter
+from .snappi import SecureEntityStaticKey
+from .snappi import SecureEntityStaticKeyTx
+from .snappi import SecureEntityStaticKeyTxSc
+from .snappi import SecureEntityStaticKeySak
+from .snappi import SecureEntityStaticKeySakIter
+from .snappi import SecureEntityStaticKeyTxScIter
+from .snappi import SecureEntityStaticKeyRekeyMode
+from .snappi import SecureEntityStaticKeyRekeyModeTimerBased
+from .snappi import SecureEntityStaticKeyRx
+from .snappi import SecureEntityStaticKeyRxSc
+from .snappi import SecureEntityStaticKeyRxScIter
+from .snappi import SecureEntityDataPlane
+from .snappi import SecureEntityDataPlaneEncapsulation
+from .snappi import SecureEntityDataPlaneTx
+from .snappi import SecureEntityDataPlaneRx
+from .snappi import SecureEntityCryptoEngine
+from .snappi import SecureEntityCryptoEngineEncryptOnly
+from .snappi import SecureEntityCryptoEngineEncryptOnlyTxSc
+from .snappi import SecureEntityCryptoEngineEncryptOnlyTxScTxPn
+from .snappi import SecureEntityCryptoEngineEncryptOnlyFixedPn
+from .snappi import SecureEntityCryptoEngineEncryptOnlyIncrementingPn
+from .snappi import SecureEntityCryptoEngineEncryptOnlyTxScIter
+from .snappi import SecureEntityCryptoEngineEncryptOnlyTrafficOptions
+from .snappi import DeviceMacsecEthernetInterfaceIter
+from .snappi import DeviceOspfv3Router
+from .snappi import Ospfv3RouterId
+from .snappi import Ospfv3RouterInstance
+from .snappi import Ospfv3GracefulRestart
+from .snappi import Ospfv3Capabilities
+from .snappi import Ospfv3Interface
+from .snappi import Ospfv3InterfaceArea
+from .snappi import Ospfv3InterfaceNetworkType
+from .snappi import Ospfv3InterfaceBroadcast
+from .snappi import Ospfv3InterfaceAdvanced
+from .snappi import Ospfv3InterfaceOptions
+from .snappi import Ospfv3InterfaceIter
+from .snappi import Ospfv3V6RouteRange
+from .snappi import Ospfv3V6RRRouteOrigin
+from .snappi import Ospfv3V6RRNssaExternal
+from .snappi import Ospfv3V6RRCapabilities
+from .snappi import Ospfv3V6RRForwardingAddress
+from .snappi import Ospfv3V6RouteRangeIter
+from .snappi import Ospfv3RouterInstanceIter
+from .snappi import DeviceRocev2Peer
+from .snappi import Rocev2V4Interface
+from .snappi import Rocev2V4Peer
+from .snappi import Rocev2QPs
+from .snappi import Rocev2ConnectionType
+from .snappi import Rocev2QPParameters
+from .snappi import Rocev2QPsIter
+from .snappi import Rocev2V4PeerIter
+from .snappi import Rocev2V4InterfaceIter
+from .snappi import Rocev2V6Interface
+from .snappi import Rocev2V6Peer
+from .snappi import Rocev2V6PeerIter
+from .snappi import Rocev2V6InterfaceIter
 from .snappi import DeviceIter
 from .snappi import Flow
 from .snappi import FlowTxRx
@@ -1114,6 +1191,91 @@ from .snappi import FlowRSVPPathObjectsCustom
 from .snappi import PatternFlowRSVPPathObjectsCustomType
 from .snappi import PatternFlowRSVPPathObjectsCustomTypeCounter
 from .snappi import FlowRSVPPathObjectsIter
+from .snappi import FlowMacsec
+from .snappi import FlowLacp
+from .snappi import PatternFlowLacpVersion
+from .snappi import PatternFlowLacpVersionCounter
+from .snappi import FlowLacpLacpdu
+from .snappi import FlowLacpduActor
+from .snappi import PatternFlowLacpduActorType
+from .snappi import PatternFlowLacpduActorTypeCounter
+from .snappi import PatternFlowLacpduActorLength
+from .snappi import PatternFlowLacpduActorLengthCounter
+from .snappi import PatternFlowLacpduActorSystemPriority
+from .snappi import PatternFlowLacpduActorSystemPriorityCounter
+from .snappi import PatternFlowLacpduActorSystemId
+from .snappi import PatternFlowLacpduActorSystemIdCounter
+from .snappi import PatternFlowLacpduActorKey
+from .snappi import PatternFlowLacpduActorKeyCounter
+from .snappi import PatternFlowLacpduActorPortPriority
+from .snappi import PatternFlowLacpduActorPortPriorityCounter
+from .snappi import PatternFlowLacpduActorPortNumber
+from .snappi import PatternFlowLacpduActorPortNumberCounter
+from .snappi import FlowLacpduActorState
+from .snappi import PatternFlowLacpduActorStateActivity
+from .snappi import PatternFlowLacpduActorStateActivityCounter
+from .snappi import PatternFlowLacpduActorStateTimeout
+from .snappi import PatternFlowLacpduActorStateTimeoutCounter
+from .snappi import PatternFlowLacpduActorStateAggregation
+from .snappi import PatternFlowLacpduActorStateAggregationCounter
+from .snappi import PatternFlowLacpduActorStateSynchronization
+from .snappi import PatternFlowLacpduActorStateSynchronizationCounter
+from .snappi import PatternFlowLacpduActorStateCollecting
+from .snappi import PatternFlowLacpduActorStateCollectingCounter
+from .snappi import PatternFlowLacpduActorStateDistributing
+from .snappi import PatternFlowLacpduActorStateDistributingCounter
+from .snappi import PatternFlowLacpduActorStateDefaulted
+from .snappi import PatternFlowLacpduActorStateDefaultedCounter
+from .snappi import PatternFlowLacpduActorStateExpired
+from .snappi import PatternFlowLacpduActorStateExpiredCounter
+from .snappi import PatternFlowLacpduActorReserved
+from .snappi import PatternFlowLacpduActorReservedCounter
+from .snappi import FlowLacpduPartner
+from .snappi import PatternFlowLacpduPartnerType
+from .snappi import PatternFlowLacpduPartnerTypeCounter
+from .snappi import PatternFlowLacpduPartnerLength
+from .snappi import PatternFlowLacpduPartnerLengthCounter
+from .snappi import PatternFlowLacpduPartnerSystemPriority
+from .snappi import PatternFlowLacpduPartnerSystemPriorityCounter
+from .snappi import PatternFlowLacpduPartnerSystemId
+from .snappi import PatternFlowLacpduPartnerSystemIdCounter
+from .snappi import PatternFlowLacpduPartnerKey
+from .snappi import PatternFlowLacpduPartnerKeyCounter
+from .snappi import PatternFlowLacpduPartnerPortPriority
+from .snappi import PatternFlowLacpduPartnerPortPriorityCounter
+from .snappi import PatternFlowLacpduPartnerPortNumber
+from .snappi import PatternFlowLacpduPartnerPortNumberCounter
+from .snappi import FlowLacpduPartnerState
+from .snappi import PatternFlowLacpduPartnerStateActivity
+from .snappi import PatternFlowLacpduPartnerStateActivityCounter
+from .snappi import PatternFlowLacpduPartnerStateTimeout
+from .snappi import PatternFlowLacpduPartnerStateTimeoutCounter
+from .snappi import PatternFlowLacpduPartnerStateAggregation
+from .snappi import PatternFlowLacpduPartnerStateAggregationCounter
+from .snappi import PatternFlowLacpduPartnerStateSynchronization
+from .snappi import PatternFlowLacpduPartnerStateSynchronizationCounter
+from .snappi import PatternFlowLacpduPartnerStateCollecting
+from .snappi import PatternFlowLacpduPartnerStateCollectingCounter
+from .snappi import PatternFlowLacpduPartnerStateDistributing
+from .snappi import PatternFlowLacpduPartnerStateDistributingCounter
+from .snappi import PatternFlowLacpduPartnerStateDefaulted
+from .snappi import PatternFlowLacpduPartnerStateDefaultedCounter
+from .snappi import PatternFlowLacpduPartnerStateExpired
+from .snappi import PatternFlowLacpduPartnerStateExpiredCounter
+from .snappi import PatternFlowLacpduPartnerReserved
+from .snappi import PatternFlowLacpduPartnerReservedCounter
+from .snappi import FlowLacpduCollector
+from .snappi import PatternFlowLacpduCollectorType
+from .snappi import PatternFlowLacpduCollectorTypeCounter
+from .snappi import PatternFlowLacpduCollectorLength
+from .snappi import PatternFlowLacpduCollectorLengthCounter
+from .snappi import PatternFlowLacpduCollectorMaxDelay
+from .snappi import PatternFlowLacpduCollectorMaxDelayCounter
+from .snappi import FlowLacpduTerminator
+from .snappi import PatternFlowLacpduTerminatorType
+from .snappi import PatternFlowLacpduTerminatorTypeCounter
+from .snappi import PatternFlowLacpduTerminatorLength
+from .snappi import PatternFlowLacpduTerminatorLengthCounter
 from .snappi import FlowHeaderIter
 from .snappi import FlowSize
 from .snappi import FlowSizeIncrement
@@ -1134,6 +1296,8 @@ from .snappi import FlowRxTxRatio
 from .snappi import FlowRxTxRatioRxCount
 from .snappi import FlowLatencyMetrics
 from .snappi import FlowPredefinedTags
+from .snappi import FlowPayload
+from .snappi import FlowPayloadFixed
 from .snappi import FlowIter
 from .snappi import Event
 from .snappi import EventCPEvents
@@ -1141,6 +1305,18 @@ from .snappi import EventDPEvents
 from .snappi import ConfigOptions
 from .snappi import PortOptions
 from .snappi import ProtocolOptions
+from .snappi import PerPortOptions
+from .snappi import PortProtocol
+from .snappi import Rocev2PerPortSettings
+from .snappi import Rocev2CNP
+from .snappi import Rocev2PriorityValue
+from .snappi import Rocev2QPConnectionType
+from .snappi import Rocev2AckAndNak
+from .snappi import Rocev2ACK
+from .snappi import Rocev2NAK
+from .snappi import Rocev2DCQCN
+from .snappi import PortProtocolIter
+from .snappi import PerPortOptionsIter
 from .snappi import Lldp
 from .snappi import LldpConnection
 from .snappi import LldpChassisId
@@ -1152,10 +1328,33 @@ from .snappi import LldpOrgInfo
 from .snappi import LldpOrgInfoType
 from .snappi import LldpOrgInfoIter
 from .snappi import LldpIter
+from .snappi import StatefulFlow
+from .snappi import Rocev2Flows
+from .snappi import Rocev2TxPorts
+from .snappi import Rocev2TransmitType
+from .snappi import Rocev2TargetLineRate
+from .snappi import Rocev2Flow
+from .snappi import Rocev2Verb
+from .snappi import Rocev2ImmediateData
+from .snappi import Rocev2FlowIter
+from .snappi import Rocev2TxPortsIter
+from .snappi import Rocev2FlowsIter
+from .snappi import EgressOnlyTracking
+from .snappi import EgressOnlyTrackingMetricTags
+from .snappi import EgressOnlyTrackingMetricTagsIter
+from .snappi import EgressOnlyTrackingFilter
+from .snappi import EgressOnlyTrackingFilterIter
+from .snappi import EgressOnlyTrackingIter
 from .snappi import Warning
 from .snappi import Error
 from .snappi import ConfigUpdate
 from .snappi import FlowsUpdate
+from .snappi import ConfigAppend
+from .snappi import ConfigAppendResources
+from .snappi import ConfigAppendResourcesIter
+from .snappi import ConfigDelete
+from .snappi import ConfigDeleteResources
+from .snappi import ConfigDeleteResourcesIter
 from .snappi import ControlState
 from .snappi import StatePort
 from .snappi import StatePortLink
@@ -1172,6 +1371,10 @@ from .snappi import StateProtocolIsis
 from .snappi import StateProtocolIsisRouters
 from .snappi import StateProtocolOspfv2
 from .snappi import StateProtocolOspfv2Routers
+from .snappi import StateProtocolOspfv3
+from .snappi import StateProtocolOspfv3Routers
+from .snappi import StateProtocolRocev2
+from .snappi import StateProtocolRocev2Peers
 from .snappi import StateTraffic
 from .snappi import StateTrafficFlowTransmit
 from .snappi import ControlAction
@@ -1195,6 +1398,10 @@ from .snappi import DeviceBgpFiniteStateMachineError
 from .snappi import DeviceBgpCustomError
 from .snappi import ActionProtocolBgpInitiateGracefulRestart
 from .snappi import ActionProtocolBgpGracefulRestartNotification
+from .snappi import ActionProtocolIsis
+from .snappi import ActionProtocolIsisInitiateRestart
+from .snappi import ActionProtocolIsisUnplannedRestart
+from .snappi import ActionProtocolIsisPlannedRestart
 from .snappi import ControlActionResponse
 from .snappi import ActionResponse
 from .snappi import ActionResponseProtocol
@@ -1225,6 +1432,17 @@ from .snappi import Dhcpv6ClientMetricsRequest
 from .snappi import Dhcpv6ServerMetricsRequest
 from .snappi import Ospfv2MetricsRequest
 from .snappi import ConvergenceRequest
+from .snappi import MacsecMetricsRequest
+from .snappi import MkaMetricsRequest
+from .snappi import Ospfv3MetricsRequest
+from .snappi import Rocev2IPv4MetricsRequest
+from .snappi import Rocev2IPv4ColumnNames
+from .snappi import Rocev2IPv6MetricsRequest
+from .snappi import Rocev2IPv6ColumnNames
+from .snappi import Rocev2FlowMetricsRequest
+from .snappi import Rocev2FlowColumnNames
+from .snappi import EgressOnlyTrackingMetricsRequest
+from .snappi import EgressOnlyTrackingTaggedMetricsFilter
 from .snappi import MetricsResponse
 from .snappi import PortMetric
 from .snappi import PortMetricIter
@@ -1265,6 +1483,26 @@ from .snappi import ConvergenceMetric
 from .snappi import ConvergenceEvent
 from .snappi import ConvergenceEventIter
 from .snappi import ConvergenceMetricIter
+from .snappi import MacsecMetric
+from .snappi import MacsecMetricIter
+from .snappi import MkaMetric
+from .snappi import MkaMetricIter
+from .snappi import Ospfv3Metric
+from .snappi import Ospfv3MetricIter
+from .snappi import Rocev2IPv4MetricPerPeer
+from .snappi import Rocev2IPv4MetricPerPeerIter
+from .snappi import Rocev2IPv6MetricPerPeer
+from .snappi import Rocev2IPv6MetricPerPeerIter
+from .snappi import Rocev2FlowMetricPerQP
+from .snappi import Rocev2FlowMetricPerQPIter
+from .snappi import EgressOnlyTrackingMetric
+from .snappi import EgressOnlyTrackingTaggedMetric
+from .snappi import EgressOnlyTrackingMetricTag
+from .snappi import EgressOnlyTrackingMetricTagIter
+from .snappi import EgressOnlyTrackingTimestamp
+from .snappi import EgressOnlyTrackingTxMetrics
+from .snappi import EgressOnlyTrackingTaggedMetricIter
+from .snappi import EgressOnlyTrackingMetricIter
 from .snappi import StatesRequest
 from .snappi import Neighborsv4StatesRequest
 from .snappi import Neighborsv6StatesRequest
@@ -1281,6 +1519,8 @@ from .snappi import Dhcpv4LeaseStateRequest
 from .snappi import Dhcpv6InterfaceStateRequest
 from .snappi import Dhcpv6LeaseStateRequest
 from .snappi import Ospfv2LsasStateRequest
+from .snappi import Ospfv3LsasStateRequest
+from .snappi import IsisIIHsStateRequest
 from .snappi import StatesResponse
 from .snappi import Neighborsv4State
 from .snappi import Neighborsv4StateIter
@@ -1409,6 +1649,44 @@ from .snappi import Ospfv2NssaLsaIter
 from .snappi import Ospfv2OpaqueLsa
 from .snappi import Ospfv2OpaqueLsaIter
 from .snappi import Ospfv2LsaStateIter
+from .snappi import Ospfv3LsaState
+from .snappi import Ospfv3RouterLsa
+from .snappi import Ospfv3LsaHeader
+from .snappi import Ospfv3Link
+from .snappi import Ospfv3LinkIter
+from .snappi import Ospfv3RouterLsaIter
+from .snappi import Ospfv3NetworkLsa
+from .snappi import Ospfv3NetworkLsaIter
+from .snappi import Ospfv3InterAreaPrefixLsa
+from .snappi import Ospfv3InterAreaPrefixLsaIter
+from .snappi import Ospfv3InterAreaRouterLsa
+from .snappi import Ospfv3InterAreaRouterLsaIter
+from .snappi import Ospfv3ExternalAsLsa
+from .snappi import Ospfv3ExternalAsLsaIter
+from .snappi import Ospfv3NssaLsa
+from .snappi import Ospfv3NssaLsaIter
+from .snappi import Ospfv3LinkLsa
+from .snappi import Ospfv3LinkLsaIter
+from .snappi import Ospfv3IntraAreaPrefixLsa
+from .snappi import Ospfv3IntraAreaPrefixLsaIter
+from .snappi import Ospfv3LsaStateIter
+from .snappi import IsisIIHsState
+from .snappi import IsisLocalIIHAdjacencyStates
+from .snappi import IsisLocalIIHState
+from .snappi import IsisIIHLocalRestartStatus
+from .snappi import IsisIIHLocalGRLastAttemptStatus
+from .snappi import IsisIIHLocalGRLastAttemptSucceeded
+from .snappi import IsisIIHLocalGRLastAttemptFailed
+from .snappi import IsisNeighborIIHState
+from .snappi import IsisIIHNeighborRestartStatus
+from .snappi import IsisIIHNeighborGRLastAttemptStatus
+from .snappi import IsisIIHNeighborGRLastAttemptSucceeded
+from .snappi import IsisIIHNeighborGRLastAttemptFailed
+from .snappi import IsisIIHNeighborTlvs
+from .snappi import IsisIIHRestartTlv
+from .snappi import IsisIIHRestartFlags
+from .snappi import IsisLocalIIHAdjacencyStatesIter
+from .snappi import IsisIIHsStateIter
 from .snappi import CaptureRequest
 from .snappi import Version
 from .snappi import Api
